{% extends "tournamentcontrol/competition/admin/_club_members.html" %}
{% load i18n %}

{% block breadcrumbs %}
	{{ block.super }}
	<li><a href="{% url 'rego:club:list' %}">{% trans "Clubs" %}</a></li>
	<li><a href="{% url 'rego:club:edit' club.pk %}">{{ club.title }}</a></li>
	<li><span>{% trans "Members" %}</span></li>
{% endblock %}

{% block table_actions %}
	<a href="{% url 'rego:edit-person' club.pk object.pk %}">{% trans "Edit" %}</a>
{% endblock %}

{% block actions %}
	<a class="button add" href="{% url 'rego:add-person' club.pk %}">{% trans "Member" %}</a>
{% endblock %}
