{% extends "touchtechnology/news/base.html" %}
{% load tz %}
{% load common news %}

{% block body_class %}{{ block.super }} detail{% endblock %}

{% block news_content %}
	<h1>{% block page_title %}{{ article.headline }}{% endblock %}</h1>

	<p class="published" data-localtime="{{ article.published|date }} @ {{ article.published|date:"G:i e" }}">
		{{ article.published|date }} @ {{ article.published|date:"G:i e" }}
	</p>

	{% if article.byline %}<p class="byline">{{ article.byline }}</p>{% endif %}

	{% block image %}
		{% if article.image %}
			<div class="img">
				<a href="{{ article.image.url }}">
					<img src="{{ article.detail_image.url }}" alt="{{ article.headline }}">
				</a>
			</div>
		{% endif %}
	{% endblock %}

	<div class="cms">
		<div class="abstract">
			{{ article.abstract|linebreaks }}
		</div>
		{% for content in article.content.all %}
			<div id="c{{ content.pk }}" class="{{ content.label }} {% if forloop.first %}first {% endif %}{% if forloop.last %} last{% endif %} {% block sectionclass %}{% endblock %}">
				{{ content.copy|safe }}
			</div>
		{% endfor %}
	</div>
{% endblock %}

{% block related_content %}
	{% related_articles article %}
{% endblock %}
