{% extends "tournamentcontrol/competition/admin/_officials.html" %}
{% load i18n %}

{% block breadcrumbs %}
	{{ block.super }}
	<li><a href="{% url 'admin:competition:club:list' %}">{% trans "Clubs" %}</a></li>
	<li><a href="{% url 'admin:competition:club:edit' club.pk %}">{{ club.title }}</a></li>
	<li><a href="{% url 'admin:competition:club-teams' club.pk %}">{% trans "Teams" %}</a></li>
	<li><span>{% trans "Officials" %}</span></li>
{% endblock %}

{% block buttons %}
	{{ block.super }}
	<a class="button" href="{% url 'admin:competition:club-teams' club.pk %}">{% trans "Cancel" %}</a>
{% endblock %}
