{% load i18n %}{% autoescape off %}
{% with username=user.email %}
{% blocktrans %}You're receiving this e-mail because you requested a password
reset for your user account at "{{ site_name }}".{% endblocktrans %}

{% trans "Please visit the following URL and set your new password." %}
{% block reset_link %}
  {{ protocol }}://{{ domain }}{% url 'accounts:password_reset_confirm' uidb64=uid token=token %}
{% endblock %}
{% blocktrans %}Just in case you've forgotten, your username is "{{ username }}".{% endblocktrans %}

{% block signature %}
{% endblock %}
{% endwith %}
{% endautoescape %}
